function [rhsu] = BurgersRHS1Dperiodic(u,time)

% function [rhsu] = BurgersRHS1Dperiodic(u, time)
% Purpose  : Evaluate RHS flux in 1D inviscid Burgers equation

Globals1D;

% Define field differences at faces
du = zeros(Nfp*Nfaces,K); du(:) = u(vmapM)-u(vmapP);

% Evaluate nonlinear flux
f = 3*u.^2;
fM = f(vmapM);
uM = u(vmapM);

df = zeros(Nfp*Nfaces,K); df(:) = (f(vmapM)-f(vmapP))/2.0;

% left
df(mapI) = (fM(mapI)-fM(mapO))/2.0;
du(mapI) = uM(mapI) - uM(mapO);

% right
df(mapO) = (fM(mapO)-fM(mapI))/2.0;
du(mapO) = uM(mapO) - uM(mapI);

% Compute flux
maxvel = 6*max(abs(u(:)));

% flux term
flux = nx.*(df) - maxvel/2.0.*du;

% local derivatives of field
dfdr = Dr*(f); 

% compute right hand sides of the semi-discrete PDE
rhsu = -(rx.*dfdr - LIFT*(Fscale.*flux));
return
