function [u,time,tmp,dt,MM] = KdV1D(u,FinalTime,ufun)

% function [u] = KdV1D(u,FinalTime)
% Purpose  : Integrate 1D KdV equation until 
%            FinalTime starting with initial condition, u.

Globals1D;
time = 0;

% Runge-Kutta residual storage  
resu = zeros(Np, K); 

% compute time step size
xmin = min(abs(x(1,:)-x(2,:)));
CFL=0.25; dt = CFL*xmin^3/max(abs(6*u(:))); 
Nsteps = ceil(FinalTime/dt); dt = FinalTime/Nsteps

MM = 250;
tmp = zeros(length(u(:)),floor(Nsteps/MM)+1);
tmp(:,1) = u(:);
count = 0;

% outer time step loop 
for tstep=1:Nsteps
  for INTRK = 1:5
    timelocal = time + rk4c(INTRK)*dt;        

    %% compute right hand side of 1D KdV equation
    % third order dispersive term
    [rhsu1] = -DispersiveLDGRHS1Dperiodic(u,timelocal);
    
    % nonlinear advection term from Burger's equation equation
    [rhsu2] = BurgersRHS1Dperiodic(u,timelocal);

    % initiate and increment Runge-Kutta residuals
    resu = rk4a(INTRK)*resu + dt*(rhsu1+rhsu2);  
    
    % update fields
    u = u+rk4b(INTRK)*resu;
  end;

  % Increment time
  time = time+dt;
  
  if mod(tstep,MM)==0
      disp(sprintf('%d/%d',tstep,Nsteps))
      count = count + 1;
      tmp(:,1+count) = u(:);
      plot(x,ufun(x,time),'k',x,u,'r')
      axis([min(x(:)) max(x(:)) -1 2])
      drawnow
  end
end
return
